@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,9 +21,7 @@ AbstractAddressBook::AbstractAddressBook()
 {
 }
 
-AbstractAddressBook::~AbstractAddressBook()
-{
-}
+AbstractAddressBook::~AbstractAddressBook() = default;
 
 bool AbstractAddressBook::selectAddressBook()
 {
